==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_fields/HOMEENTRYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour HOMEENTRYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="HOMEENTRYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMETYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HOMEENTRYID_Type", propOrder = {
    "homecode",
    "hometype"
})
public class HOMEENTRYID_Type {

    @XmlElement(name = "HOMECODE", required = true)
    protected String homecode;
    @XmlElement(name = "HOMETYPE", required = true)
    protected String hometype;

    /**
     * Obtient la valeur de la propriété homecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHOMECODE() {
        return homecode;
    }

    /**
     * Définit la valeur de la propriété homecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHOMECODE(String value) {
        this.homecode = value;
    }

    /**
     * Obtient la valeur de la propriété hometype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHOMETYPE() {
        return hometype;
    }

    /**
     * Définit la valeur de la propriété hometype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHOMETYPE(String value) {
        this.hometype = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/HOMEENTRYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for HOMEENTRYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HOMEENTRYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOMETYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HOMEENTRYID_Type", propOrder = {
    "homecode",
    "hometype"
})
public class HOMEENTRYID_Type {

    @XmlElement(name = "HOMECODE", required = true)
    protected String homecode;
    @XmlElement(name = "HOMETYPE", required = true)
    protected String hometype;

    /**
     * Gets the value of the homecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHOMECODE() {
        return homecode;
    }

    /**
     * Sets the value of the homecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHOMECODE(String value) {
        this.homecode = value;
    }

    /**
     * Gets the value of the hometype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHOMETYPE() {
        return hometype;
    }

    /**
     * Sets the value of the hometype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHOMETYPE(String value) {
        this.hometype = value;
    }

}
